;; Generated package description from cursor-undo.el  -*- no-byte-compile: t -*-
(define-package "cursor-undo" "1.1.5" "Undo Cursor Movement" 'nil :commit "e82084c3d491ff7199e14cc8da69c250b9bda492" :url "https://elpa.gnu.org/packages/cursor-undo.html" :authors '(("Luke Lee" . "luke.yx.lee@gmail.com")) :maintainer '("Luke Lee" . "luke.yx.lee@gmail.com") :keywords '("undo" "cursor"))
